@@ -215,15 +215,24 @@ namespace ranges
 #define RANGES_DIAGNOSTIC_IGNORE_MULTIPLE_ASSIGNMENT_OPERATORS \
     RANGES_DIAGNOSTIC_IGNORE(4522)
 #define RANGES_DIAGNOSTIC_IGNORE_VOID_PTR_DEREFERENCE
+#define RANGES_DIAGNOSTIC_KEYWORD_MACRO
 
 #define RANGES_CXX_VER _MSVC_LANG
 
-#if _MSC_VER < 1920 || _MSVC_LANG < 201703L || !defined(_MSVC_TRADITIONAL) || \
-    _MSVC_TRADITIONAL != 0
-#error range-v3 requires Visual Studio 2019 with the /std:c++17 (or /std:c++latest) /permissive- and /experimental:preprocessor options.
+#if _MSC_VER < 1920 || _MSVC_LANG < 201703L
+#error range-v3 requires Visual Studio 2019 with the /std:c++17 (or /std:c++latest) and /permissive- options.
 #endif
 
+#if _MSC_VER < 1927
+#define RANGES_WORKAROUND_MSVC_895622 // Error when phase 1 name binding finds only
+                                      // deleted function
+
+#if _MSC_VER < 1925
+#define RANGES_WORKAROUND_MSVC_779708 // ADL for operands of function type [No workaround]
+
 #if _MSC_VER < 1923
+#define RANGES_WORKAROUND_MSVC_573728 // rvalues of array types bind to lvalue references
+                                      // [no workaround]
 #define RANGES_WORKAROUND_MSVC_934330 // Deduction guide not correctly preferred to copy
                                       // deduction candidate [No workaround]
 
@@ -244,6 +253,8 @@ namespace ranges
 #endif                                // _MSC_VER < 1921
 #endif                                // _MSC_VER < 1922
 #endif                                // _MSC_VER < 1923
+#endif                                // _MSC_VER < 1925
+#endif                                // _MSC_VER < 1926
 
 #if 1 // Fixed in 1920, but more bugs hiding behind workaround
 #define RANGES_WORKAROUND_MSVC_701385 // Yet another alias expansion error
@@ -251,22 +262,17 @@ namespace ranges
 
 #define RANGES_WORKAROUND_MSVC_249830 // constexpr and arguments that aren't subject to
                                       // lvalue-to-rvalue conversion
-#define RANGES_WORKAROUND_MSVC_573728 // rvalues of array types bind to lvalue references
-                                      // [no workaround]
 #define RANGES_WORKAROUND_MSVC_677925 // Bogus C2676 "binary '++': '_Ty' does not define
                                       // this operator"
 #define RANGES_WORKAROUND_MSVC_683388 // decltype(*i) is incorrectly an rvalue reference
                                       // for pointer-to-array i
 #define RANGES_WORKAROUND_MSVC_688606 // SFINAE failing to account for access control
                                       // during specialization matching
-#define RANGES_WORKAROUND_MSVC_779708 // ADL for operands of function type [No workaround]
 #define RANGES_WORKAROUND_MSVC_786312 // Yet another mixed-pack-expansion failure
 #define RANGES_WORKAROUND_MSVC_792338 // Failure to match specialization enabled via call
                                       // to constexpr function
 #define RANGES_WORKAROUND_MSVC_835948 // Silent bad codegen destroying sized_generator [No
                                       // workaround]
-#define RANGES_WORKAROUND_MSVC_895622 // Error when phase 1 name binding finds only
-                                      // deleted function
 #define RANGES_WORKAROUND_MSVC_934264 // Explicitly-defaulted inherited default
                                       // constructor is not correctly implicitly constexpr
 #if _MSVC_LANG <= 201703L
@@ -323,6 +329,7 @@ namespace ranges
 #define RANGES_DIAGNOSTIC_IGNORE_MULTIPLE_ASSIGNMENT_OPERATORS
 #define RANGES_DIAGNOSTIC_IGNORE_VOID_PTR_DEREFERENCE \
     RANGES_DIAGNOSTIC_IGNORE("-Wvoid-ptr-dereference")
+#define RANGES_DIAGNOSTIC_KEYWORD_MACRO RANGES_DIAGNOSTIC_IGNORE("-Wkeyword-macro")
 
 #define RANGES_WORKAROUND_CWG_1554
 #ifdef __clang__
@@ -339,9 +346,6 @@ namespace ranges
 #define RANGES_WORKAROUND_GCC_91525 /* Workaround strange GCC ICE */
 #endif
 #if __GNUC__ >= 9
-#ifdef __cpp_concepts
-#define RANGES_WORKAROUND_GCC_89953 // ICE in nothrow_spec_p, at cp/except.c:1244
-#endif
 #if __GNUC__ == 9 && __GNUC_MINOR__ < 3 && __cplusplus == RANGES_CXX_STD_17
 #define RANGES_WORKAROUND_GCC_91923 // Failure-to-SFINAE with class type NTTP in C++17
 #endif
@@ -375,6 +379,7 @@ namespace ranges
 #define RANGES_DIAGNOSTIC_IGNORE_TRUNCATION
 #define RANGES_DIAGNOSTIC_IGNORE_MULTIPLE_ASSIGNMENT_OPERATORS
 #define RANGES_DIAGNOSTIC_IGNORE_VOID_PTR_DEREFERENCE
+#define RANGES_DIAGNOSTIC_KEYWORD_MACRO
 #endif
 
 // Configuration via feature-test macros, with fallback to __cplusplus
@@ -515,9 +520,18 @@ namespace ranges
 // #endif
 
 #ifndef RANGES_CXX_COROUTINES
-#ifdef __cpp_coroutines
+#if defined(__cpp_coroutines) && defined(__has_include)
+#if __has_include(<coroutine>)
 #define RANGES_CXX_COROUTINES __cpp_coroutines
-#else
+#define RANGES_COROUTINES_HEADER <coroutine>
+#define RANGES_COROUTINES_NS std
+#elif __has_include(<experimental/coroutine>)
+#define RANGES_CXX_COROUTINES __cpp_coroutines
+#define RANGES_COROUTINES_HEADER <experimental/coroutine>
+#define RANGES_COROUTINES_NS std::experimental
+#endif
+#endif
+#ifndef RANGES_CXX_COROUTINES
 #define RANGES_CXX_COROUTINES RANGES_CXX_FEATURE(COROUTINES)
 #endif
 #endif
@@ -678,7 +692,9 @@ namespace ranges
 #define RANGES_IS_SAME(...) std::is_same<__VA_ARGS__>::value
 #endif
 
-#if defined(__has_cpp_attribute) && __has_cpp_attribute(no_unique_address)
+// https://gcc.gnu.org/bugzilla/show_bug.cgi?id=93667
+#if defined(__has_cpp_attribute) && __has_cpp_attribute(no_unique_address) && \
+    !(defined(__GNUC__) && !defined(__clang__) && __GNUC__ >= 10)
 #define RANGES_NO_UNIQUE_ADDRESS [[no_unique_address]]
 #else
 #define RANGES_NO_UNIQUE_ADDRESS
