@@ -40,7 +40,7 @@ test_char()
     CHECK(ca[3] == 1);
     CHECK(i == Iter(ca + 4));
 
-    auto rng = ranges::make_iterator_range(Iter(ca), Sent(ca+n));
+    auto rng = ranges::make_subrange(Iter(ca), Sent(ca+n));
     i = ranges::fill(rng, char(2));
     CHECK(ca[0] == 2);
     CHECK(ca[1] == 2);
@@ -48,12 +48,12 @@ test_char()
     CHECK(ca[3] == 2);
     CHECK(i == Iter(ca + 4));
 
-    auto j = ranges::fill(ranges::make_iterator_range(Iter(ca), Sent(ca+n)), char(3));
+    auto j = ranges::fill(::MakeTestRange(Iter(ca), Sent(ca+n)), char(3));
     CHECK(ca[0] == 3);
     CHECK(ca[1] == 3);
     CHECK(ca[2] == 3);
     CHECK(ca[3] == 3);
-    CHECK(j.get_unsafe() == Iter(ca + 4));
+    CHECK(::is_dangling(j));
 }
 
 template<class Iter, class Sent = Iter>
@@ -68,7 +68,7 @@ test_int()
     CHECK(ia[2] == 1);
     CHECK(ia[3] == 1);
 
-    auto rng = ranges::make_iterator_range(Iter(ia), Sent(ia+n));
+    auto rng = ranges::make_subrange(Iter(ia), Sent(ia+n));
     ranges::fill(rng, 2);
     CHECK(ia[0] == 2);
     CHECK(ia[2] == 2);
@@ -78,23 +78,23 @@ test_int()
 
 int main()
 {
-    test_char<forward_iterator<char*> >();
-    test_char<bidirectional_iterator<char*> >();
-    test_char<random_access_iterator<char*> >();
+    test_char<ForwardIterator<char*> >();
+    test_char<BidirectionalIterator<char*> >();
+    test_char<RandomAccessIterator<char*> >();
     test_char<char*>();
 
-    test_char<forward_iterator<char*>, sentinel<char*> >();
-    test_char<bidirectional_iterator<char*>, sentinel<char*> >();
-    test_char<random_access_iterator<char*>, sentinel<char*> >();
+    test_char<ForwardIterator<char*>, Sentinel<char*> >();
+    test_char<BidirectionalIterator<char*>, Sentinel<char*> >();
+    test_char<RandomAccessIterator<char*>, Sentinel<char*> >();
 
-    test_int<forward_iterator<int*> >();
-    test_int<bidirectional_iterator<int*> >();
-    test_int<random_access_iterator<int*> >();
+    test_int<ForwardIterator<int*> >();
+    test_int<BidirectionalIterator<int*> >();
+    test_int<RandomAccessIterator<int*> >();
     test_int<int*>();
 
-    test_int<forward_iterator<int*>, sentinel<int*> >();
-    test_int<bidirectional_iterator<int*>, sentinel<int*> >();
-    test_int<random_access_iterator<int*>, sentinel<int*> >();
+    test_int<ForwardIterator<int*>, Sentinel<int*> >();
+    test_int<BidirectionalIterator<int*>, Sentinel<int*> >();
+    test_int<RandomAccessIterator<int*>, Sentinel<int*> >();
 
     return ::test_result();
 }
