@@ -21,6 +21,7 @@
 #include <vector>
 #include <range/v3/core.hpp>
 #include <range/v3/algorithm/generate.hpp>
+#include <range/v3/iterator/insert_iterators.hpp>
 #include <range/v3/view/counted.hpp>
 #include "../simple_test.hpp"
 #include "../test_utils.hpp"
@@ -40,37 +41,37 @@ test()
 {
     const unsigned n = 4;
     int ia[n] = {0};
-    std::pair<Iter, gen_test> res = ranges::generate(Iter(ia), Sent(ia + n), gen_test(1));
+    ranges::generate_result<Iter, gen_test> res = ranges::generate(Iter(ia), Sent(ia + n), gen_test(1));
     CHECK(ia[0] == 1);
     CHECK(ia[1] == 2);
     CHECK(ia[2] == 3);
     CHECK(ia[3] == 4);
-    CHECK(res.first == Iter(ia + n));
-    CHECK(res.second.i_ == 5);
+    CHECK(res.out == Iter(ia + n));
+    CHECK(res.fun.i_ == 5);
 
-    auto rng = ranges::make_iterator_range(Iter(ia), Sent(ia + n));
-    res = ranges::generate(rng, res.second);
+    auto rng = ::MakeTestRange(Iter(ia), Sent(ia + n));
+    res = ranges::generate(rng, res.fun);
     CHECK(ia[0] == 5);
     CHECK(ia[1] == 6);
     CHECK(ia[2] == 7);
     CHECK(ia[3] == 8);
-    CHECK(res.first == Iter(ia + n));
-    CHECK(res.second.i_ == 9);
+    CHECK(res.out == Iter(ia + n));
+    CHECK(res.fun.i_ == 9);
 
-    auto res2 = ranges::generate(std::move(rng), res.second);
+    auto res2 = ranges::generate(std::move(rng), res.fun);
     CHECK(ia[0] == 9);
     CHECK(ia[1] == 10);
     CHECK(ia[2] == 11);
     CHECK(ia[3] == 12);
-    CHECK(res2.first.get_unsafe() == Iter(ia + n));
-    CHECK(res2.second.i_ == 13);
+    CHECK(::is_dangling(res2.out));
+    CHECK(res2.fun.i_ == 13);
 }
 
 void test2()
 {
     // Test ranges::generate with a genuine output range
     std::vector<int> v;
-    auto rng = ranges::view::counted(ranges::back_inserter(v), 5);
+    auto rng = ranges::views::counted(ranges::back_inserter(v), 5);
     ranges::generate(rng, gen_test(1));
     CHECK(v.size() == 5u);
     CHECK(v[0] == 1);
@@ -82,14 +83,14 @@ void test2()
 
 int main()
 {
-    test<forward_iterator<int*> >();
-    test<bidirectional_iterator<int*> >();
-    test<random_access_iterator<int*> >();
+    test<ForwardIterator<int*> >();
+    test<BidirectionalIterator<int*> >();
+    test<RandomAccessIterator<int*> >();
     test<int*>();
 
-    test<forward_iterator<int*>, sentinel<int*> >();
-    test<bidirectional_iterator<int*>, sentinel<int*> >();
-    test<random_access_iterator<int*>, sentinel<int*> >();
+    test<ForwardIterator<int*>, Sentinel<int*> >();
+    test<BidirectionalIterator<int*>, Sentinel<int*> >();
+    test<RandomAccessIterator<int*>, Sentinel<int*> >();
 
     test2();
 
