@@ -77,31 +77,31 @@ test_range()
 {
     {
         const int ia[] = {1, 2, 3, 4, 5, 6};
-        CHECK(!ranges::is_partitioned(ranges::make_iterator_range(Iter(ranges::begin(ia)),
+        CHECK(!ranges::is_partitioned(ranges::make_subrange(Iter(ranges::begin(ia)),
                                                     Sent(ranges::end(ia))),
                                       is_odd()));
     }
     {
         const int ia[] = {1, 3, 5, 2, 4, 6};
-        CHECK( ranges::is_partitioned(ranges::make_iterator_range(Iter(ranges::begin(ia)),
+        CHECK( ranges::is_partitioned(ranges::make_subrange(Iter(ranges::begin(ia)),
                                                     Sent(ranges::end(ia))),
                                       is_odd()));
     }
     {
         const int ia[] = {2, 4, 6, 1, 3, 5};
-        CHECK(!ranges::is_partitioned(ranges::make_iterator_range(Iter(ranges::begin(ia)),
+        CHECK(!ranges::is_partitioned(ranges::make_subrange(Iter(ranges::begin(ia)),
                                                     Sent(ranges::end(ia))),
                                       is_odd()));
     }
     {
         const int ia[] = {1, 3, 5, 2, 4, 6, 7};
-        CHECK(!ranges::is_partitioned(ranges::make_iterator_range(Iter(ranges::begin(ia)),
+        CHECK(!ranges::is_partitioned(ranges::make_subrange(Iter(ranges::begin(ia)),
                                                     Sent(ranges::end(ia))),
                                       is_odd()));
     }
     {
         const int ia[] = {1, 3, 5, 2, 4, 6, 7};
-        CHECK( ranges::is_partitioned(ranges::make_iterator_range(Iter(ranges::begin(ia)),
+        CHECK( ranges::is_partitioned(ranges::make_subrange(Iter(ranges::begin(ia)),
                                                     Sent(ranges::begin(ia))),
                                       is_odd()));
     }
@@ -114,18 +114,15 @@ struct S
 
 int main()
 {
-    test_iter<input_iterator<const int*> >();
-    test_iter<input_iterator<const int*>, sentinel<const int*>>();
+    test_iter<InputIterator<const int*> >();
+    test_iter<InputIterator<const int*>, Sentinel<const int*>>();
 
-    test_range<input_iterator<const int*> >();
-    test_range<input_iterator<const int*>, sentinel<const int*>>();
+    test_range<InputIterator<const int*> >();
+    test_range<InputIterator<const int*>, Sentinel<const int*>>();
 
     // Test projections
     const S ia[] = {S{1}, S{3}, S{5}, S{2}, S{4}, S{6}};
     CHECK( ranges::is_partitioned(ia, is_odd(), &S::i) );
 
-    // Test initializer list
-    CHECK( ranges::is_partitioned({S{1}, S{3}, S{5}, S{2}, S{4}, S{6}}, is_odd(), &S::i) );
-
     return ::test_result();
 }
