@@ -22,10 +22,11 @@
 //
 //===----------------------------------------------------------------------===//
 
+#include <functional>
 #include <iostream>
 #include <memory>
 #include <utility>
-#include <functional>
+#include <vector>
 #include <range/v3/core.hpp>
 #include <range/v3/algorithm/remove_if.hpp>
 #include "../simple_test.hpp"
@@ -37,7 +38,7 @@ void
 test_iter()
 {
     int ia[] = {0, 1, 2, 3, 4, 2, 3, 4, 2};
-    constexpr unsigned sa = ranges::size(ia);
+    constexpr auto sa = ranges::size(ia);
     using namespace std::placeholders;
     Iter r = ranges::remove_if(Iter(ia), Sent(ia+sa), std::bind(std::equal_to<int>(), _1, 2));
     CHECK(base(r) == ia + sa-3);
@@ -54,9 +55,9 @@ void
 test_range()
 {
     int ia[] = {0, 1, 2, 3, 4, 2, 3, 4, 2};
-    constexpr unsigned sa = ranges::size(ia);
+    constexpr auto sa = ranges::size(ia);
     using namespace std::placeholders;
-    Iter r = ranges::remove_if(::as_lvalue(ranges::make_iterator_range(Iter(ia), Sent(ia+sa))), std::bind(std::equal_to<int>(), _1, 2));
+    Iter r = ranges::remove_if(::as_lvalue(ranges::make_subrange(Iter(ia), Sent(ia+sa))), std::bind(std::equal_to<int>(), _1, 2));
     CHECK(base(r) == ia + sa-3);
     CHECK(ia[0] == 0);
     CHECK(ia[1] == 1);
@@ -111,7 +112,7 @@ test_range_rvalue()
     ia[6].reset(new int(3));
     ia[7].reset(new int(4));
     ia[8].reset(new int(2));
-    Iter r = ranges::remove_if(::as_lvalue(ranges::make_iterator_range(Iter(ia), Sent(ia+sa))), pred());
+    Iter r = ranges::remove_if(::as_lvalue(ranges::make_subrange(Iter(ia), Sent(ia+sa))), pred());
     CHECK(base(r) == ia + sa-3);
     CHECK(*ia[0] == 0);
     CHECK(*ia[1] == 1);
@@ -128,42 +129,42 @@ struct S
 
 int main()
 {
-    test_iter<forward_iterator<int*> >();
-    test_iter<bidirectional_iterator<int*> >();
-    test_iter<random_access_iterator<int*> >();
+    test_iter<ForwardIterator<int*> >();
+    test_iter<BidirectionalIterator<int*> >();
+    test_iter<RandomAccessIterator<int*> >();
     test_iter<int*>();
-    test_iter<forward_iterator<int*>, sentinel<int*>>();
-    test_iter<bidirectional_iterator<int*>, sentinel<int*>>();
-    test_iter<random_access_iterator<int*>, sentinel<int*>>();
+    test_iter<ForwardIterator<int*>, Sentinel<int*>>();
+    test_iter<BidirectionalIterator<int*>, Sentinel<int*>>();
+    test_iter<RandomAccessIterator<int*>, Sentinel<int*>>();
 
-    test_range<forward_iterator<int*> >();
-    test_range<bidirectional_iterator<int*> >();
-    test_range<random_access_iterator<int*> >();
+    test_range<ForwardIterator<int*> >();
+    test_range<BidirectionalIterator<int*> >();
+    test_range<RandomAccessIterator<int*> >();
     test_range<int*>();
-    test_range<forward_iterator<int*>, sentinel<int*>>();
-    test_range<bidirectional_iterator<int*>, sentinel<int*>>();
-    test_range<random_access_iterator<int*>, sentinel<int*>>();
+    test_range<ForwardIterator<int*>, Sentinel<int*>>();
+    test_range<BidirectionalIterator<int*>, Sentinel<int*>>();
+    test_range<RandomAccessIterator<int*>, Sentinel<int*>>();
 
-    test_iter_rvalue<forward_iterator<std::unique_ptr<int>*> >();
-    test_iter_rvalue<bidirectional_iterator<std::unique_ptr<int>*> >();
-    test_iter_rvalue<random_access_iterator<std::unique_ptr<int>*> >();
+    test_iter_rvalue<ForwardIterator<std::unique_ptr<int>*> >();
+    test_iter_rvalue<BidirectionalIterator<std::unique_ptr<int>*> >();
+    test_iter_rvalue<RandomAccessIterator<std::unique_ptr<int>*> >();
     test_iter_rvalue<std::unique_ptr<int>*>();
-    test_iter_rvalue<forward_iterator<std::unique_ptr<int>*>, sentinel<std::unique_ptr<int>*>>();
-    test_iter_rvalue<bidirectional_iterator<std::unique_ptr<int>*>, sentinel<std::unique_ptr<int>*>>();
-    test_iter_rvalue<random_access_iterator<std::unique_ptr<int>*>, sentinel<std::unique_ptr<int>*>>();
+    test_iter_rvalue<ForwardIterator<std::unique_ptr<int>*>, Sentinel<std::unique_ptr<int>*>>();
+    test_iter_rvalue<BidirectionalIterator<std::unique_ptr<int>*>, Sentinel<std::unique_ptr<int>*>>();
+    test_iter_rvalue<RandomAccessIterator<std::unique_ptr<int>*>, Sentinel<std::unique_ptr<int>*>>();
 
-    test_range_rvalue<forward_iterator<std::unique_ptr<int>*> >();
-    test_range_rvalue<bidirectional_iterator<std::unique_ptr<int>*> >();
-    test_range_rvalue<random_access_iterator<std::unique_ptr<int>*> >();
+    test_range_rvalue<ForwardIterator<std::unique_ptr<int>*> >();
+    test_range_rvalue<BidirectionalIterator<std::unique_ptr<int>*> >();
+    test_range_rvalue<RandomAccessIterator<std::unique_ptr<int>*> >();
     test_range_rvalue<std::unique_ptr<int>*>();
-    test_range_rvalue<forward_iterator<std::unique_ptr<int>*>, sentinel<std::unique_ptr<int>*>>();
-    test_range_rvalue<bidirectional_iterator<std::unique_ptr<int>*>, sentinel<std::unique_ptr<int>*>>();
-    test_range_rvalue<random_access_iterator<std::unique_ptr<int>*>, sentinel<std::unique_ptr<int>*>>();
+    test_range_rvalue<ForwardIterator<std::unique_ptr<int>*>, Sentinel<std::unique_ptr<int>*>>();
+    test_range_rvalue<BidirectionalIterator<std::unique_ptr<int>*>, Sentinel<std::unique_ptr<int>*>>();
+    test_range_rvalue<RandomAccessIterator<std::unique_ptr<int>*>, Sentinel<std::unique_ptr<int>*>>();
 
     {
         // Check projection
         S ia[] = {S{0}, S{1}, S{2}, S{3}, S{4}, S{2}, S{3}, S{4}, S{2}};
-        constexpr unsigned sa = ranges::size(ia);
+        constexpr auto sa = ranges::size(ia);
         using namespace std::placeholders;
         S* r = ranges::remove_if(ia, std::bind(std::equal_to<int>(), _1, 2), &S::i);
         CHECK(r == ia + sa-3);
@@ -176,12 +177,13 @@ int main()
     }
 
     {
-        // Check rvalue range
+        // Check rvalue ranges
         S ia[] = {S{0}, S{1}, S{2}, S{3}, S{4}, S{2}, S{3}, S{4}, S{2}};
-        constexpr unsigned sa = ranges::size(ia);
         using namespace std::placeholders;
-        auto r = ranges::remove_if(ranges::view::all(ia), std::bind(std::equal_to<int>(), _1, 2), &S::i);
-        CHECK(r.get_unsafe() == ia + sa-3);
+        auto r0 = ranges::remove_if(std::move(ia), std::bind(std::equal_to<int>(), _1, 2), &S::i);
+#ifndef RANGES_WORKAROUND_MSVC_573728
+        static_assert(std::is_same<decltype(r0), ranges::dangling>::value, "");
+#endif // RANGES_WORKAROUND_MSVC_573728
         CHECK(ia[0].i == 0);
         CHECK(ia[1].i == 1);
         CHECK(ia[2].i == 3);
@@ -189,14 +191,15 @@ int main()
         CHECK(ia[4].i == 3);
         CHECK(ia[5].i == 4);
 
-        // Some tests for sanitizing an algorithm result
-        static_assert(std::is_same<decltype(r), ranges::dangling<S *>>::value, "");
-        auto r2 = ranges::sanitize(r);
-        static_assert(std::is_same<decltype(r2), ranges::dangling<>>::value, "");
-        auto r3 = ranges::sanitize(const_cast<decltype(r) const &>(r));
-        static_assert(std::is_same<decltype(r3), ranges::dangling<>>::value, "");
-        auto r4 = ranges::sanitize(std::move(r));
-        static_assert(std::is_same<decltype(r4), ranges::dangling<>>::value, "");
+        std::vector<S> vec{S{0}, S{1}, S{2}, S{3}, S{4}, S{2}, S{3}, S{4}, S{2}};
+        auto r1 = ranges::remove_if(std::move(vec), std::bind(std::equal_to<int>(), _1, 2), &S::i);
+        static_assert(std::is_same<decltype(r1), ranges::dangling>::value, "");
+        CHECK(vec[0].i == 0);
+        CHECK(vec[1].i == 1);
+        CHECK(vec[2].i == 3);
+        CHECK(vec[3].i == 4);
+        CHECK(vec[4].i == 3);
+        CHECK(vec[5].i == 4);
     }
 
     return ::test_result();
