@@ -66,46 +66,46 @@ void test()
     {
         int ia[] = {0};
         const unsigned sa = sizeof(ia)/sizeof(ia[0]);
-        Iter i0 = ranges::reverse(::as_lvalue(ranges::make_iterator_range(Iter(ia), Sent(ia))));
+        Iter i0 = ranges::reverse(::as_lvalue(ranges::make_subrange(Iter(ia), Sent(ia))));
         ::check_equal(ia, {0});
         CHECK(i0 == Iter(ia));
-        Iter i1 = ranges::reverse(::as_lvalue(ranges::make_iterator_range(Iter(ia), Sent(ia+sa))));
+        Iter i1 = ranges::reverse(::as_lvalue(ranges::make_subrange(Iter(ia), Sent(ia+sa))));
         ::check_equal(ia, {0});
         CHECK(i1 == Iter(ia+sa));
 
         int ib[] = {0, 1};
         const unsigned sb = sizeof(ib)/sizeof(ib[0]);
-        Iter i2 = ranges::reverse(::as_lvalue(ranges::make_iterator_range(Iter(ib), Sent(ib+sb))));
+        Iter i2 = ranges::reverse(::as_lvalue(ranges::make_subrange(Iter(ib), Sent(ib+sb))));
         ::check_equal(ib, {1, 0});
         CHECK(i2 == Iter(ib+sb));
 
         int ic[] = {0, 1, 2};
         const unsigned sc = sizeof(ic)/sizeof(ic[0]);
-        Iter i3 = ranges::reverse(::as_lvalue(ranges::make_iterator_range(Iter(ic), Sent(ic+sc))));
+        Iter i3 = ranges::reverse(::as_lvalue(ranges::make_subrange(Iter(ic), Sent(ic+sc))));
         ::check_equal(ic, {2, 1, 0});
         CHECK(i3 == Iter(ic+sc));
 
         int id[] = {0, 1, 2, 3};
         const unsigned sd = sizeof(id)/sizeof(id[0]);
-        Iter i4 = ranges::reverse(::as_lvalue(ranges::make_iterator_range(Iter(id), Sent(id+sd))));
+        Iter i4 = ranges::reverse(::as_lvalue(ranges::make_subrange(Iter(id), Sent(id+sd))));
         ::check_equal(id, {3, 2, 1, 0});
         CHECK(i4 == Iter(id+sd));
 
         // rvalue range
-        auto i5 = ranges::reverse(ranges::make_iterator_range(Iter(id), Sent(id+sd)));
+        auto i5 = ranges::reverse(ranges::make_subrange(Iter(id), Sent(id+sd)));
         ::check_equal(id, {0, 1, 2, 3});
-        CHECK(i5.get_unsafe() == Iter(id+sd));
+        CHECK(i5 == Iter(id+sd));
     }
 }
 
 int main()
 {
-    test<bidirectional_iterator<int *>>();
-    test<random_access_iterator<int *>>();
+    test<BidirectionalIterator<int *>>();
+    test<RandomAccessIterator<int *>>();
     test<int*>();
 
-    test<bidirectional_iterator<int *>, sentinel<int*>>();
-    test<random_access_iterator<int *>, sentinel<int*>>();
+    test<BidirectionalIterator<int *>, Sentinel<int*>>();
+    test<RandomAccessIterator<int *>, Sentinel<int*>>();
 
     return ::test_result();
 }
