@@ -23,6 +23,7 @@
 //===----------------------------------------------------------------------===//
 
 #include <utility>
+#include <vector>
 #include <range/v3/core.hpp>
 #include <range/v3/algorithm/rotate.hpp>
 #include "../simple_test.hpp"
@@ -32,7 +33,7 @@ template<class Iter, class Sent = Iter>
 void test()
 {
     using namespace ranges;
-    using Res = iterator_range<Iter>;
+    using Res = subrange<Iter>;
 
     int ia[] = {0};
     const unsigned sa = sizeof(ia)/sizeof(ia[0]);
@@ -252,20 +253,44 @@ void test()
 
 int main()
 {
-    test<forward_iterator<int *>>();
-    test<bidirectional_iterator<int *>>();
-    test<random_access_iterator<int *>>();
+    test<ForwardIterator<int *>>();
+    test<BidirectionalIterator<int *>>();
+    test<RandomAccessIterator<int *>>();
 
-    test<forward_iterator<int *>, sentinel<int*>>();
-    test<bidirectional_iterator<int *>, sentinel<int*>>();
-    test<random_access_iterator<int *>, sentinel<int*>>();
+    test<ForwardIterator<int *>, Sentinel<int*>>();
+    test<BidirectionalIterator<int *>, Sentinel<int*>>();
+    test<RandomAccessIterator<int *>, Sentinel<int*>>();
 
-    // test rvalue range
+    // test rvalue ranges
     {
         int rgi[] = {0,1,2,3,4,5};
-        auto r = ranges::rotate(ranges::view::all(rgi), rgi+2);
-        CHECK(r.get_unsafe().begin() == rgi+4);
-        CHECK(r.get_unsafe().end() == ranges::end(rgi));
+        auto r = ranges::rotate(ranges::views::all(rgi), rgi+2);
+        CHECK(r.begin() == rgi+4);
+        CHECK(r.end() == ranges::end(rgi));
+        CHECK(rgi[0] == 2);
+        CHECK(rgi[1] == 3);
+        CHECK(rgi[2] == 4);
+        CHECK(rgi[3] == 5);
+        CHECK(rgi[4] == 0);
+        CHECK(rgi[5] == 1);
+    }
+    {
+        int rgi[] = {0,1,2,3,4,5};
+        auto r = ranges::rotate(std::move(rgi), rgi+2);
+#ifndef RANGES_WORKAROUND_MSVC_573728
+        CHECK(::is_dangling(r));
+#endif // RANGES_WORKAROUND_MSVC_573728
+        CHECK(rgi[0] == 2);
+        CHECK(rgi[1] == 3);
+        CHECK(rgi[2] == 4);
+        CHECK(rgi[3] == 5);
+        CHECK(rgi[4] == 0);
+        CHECK(rgi[5] == 1);
+    }
+    {
+        std::vector<int> rgi{0,1,2,3,4,5};
+        auto r = ranges::rotate(std::move(rgi), rgi.begin()+2);
+        CHECK(::is_dangling(r));
         CHECK(rgi[0] == 2);
         CHECK(rgi[1] == 3);
         CHECK(rgi[2] == 4);
