@@ -28,15 +28,17 @@
 #include <range/v3/algorithm/equal.hpp>
 #include <range/v3/algorithm/sample.hpp>
 #include <range/v3/numeric/iota.hpp>
+#include <range/v3/iterator/move_iterators.hpp>
 #include "../simple_test.hpp"
 #include "../test_utils.hpp"
 #include "../test_iterators.hpp"
 
 namespace
 {
-    template<typename I, typename S,
-        CONCEPT_REQUIRES_(ranges::Sentinel<S, I>())>
-    bool in_sequence(I first, I mid, S last)
+    template<typename I, typename S>
+    auto in_sequence(I first, I mid, S last) ->
+        CPP_ret(bool)(
+            requires ranges::sentinel_for<S, I>)
     {
         for (; first != mid; ++first)
             RANGES_ENSURE(first != last);
@@ -57,25 +59,25 @@ int main()
         std::minstd_rand g1, g2 = g1;
 
         {
-            auto result = ranges::sample(random_access_iterator<int*>(i.data()),
-                sentinel<int*>(i.data()+N), a.begin(), K, g1);
-            CHECK(in_sequence(i.data(), result.in().base(), i.data() + N));
-            CHECK(result.out() == a.end());
+            auto result = ranges::sample(RandomAccessIterator<int*>(i.data()),
+                Sentinel<int*>(i.data()+N), a.begin(), K, g1);
+            CHECK(in_sequence(i.data(), result.in.base(), i.data() + N));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, c));
         }
 
         {
             auto result = ranges::sample(i.begin(), i.end(), b.begin(), K, g1);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(!ranges::equal(a, b));
             CHECK(!ranges::equal(b, c));
         }
 
         {
             auto result = ranges::sample(i.begin(), i.end(), c.begin(), K, g2);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == c.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == c.end());
             CHECK(ranges::equal(a, c));
         }
     }
@@ -85,26 +87,26 @@ int main()
         ranges::iota(i, 0);
         std::array<int, K> a{}, b{}, c{};
         std::minstd_rand g1, g2 = g1;
-        auto rng = ranges::make_iterator_range(random_access_iterator<int*>(i.data()), sentinel<int*>(i.data() + N));
+        auto rng = ranges::make_subrange(RandomAccessIterator<int*>(i.data()), Sentinel<int*>(i.data() + N));
 
         {
             auto result = ranges::sample(rng, a.begin(), K, g1);
-            CHECK(in_sequence(ranges::begin(rng), result.in(), ranges::end(rng)));
-            CHECK(result.out() == a.end());
+            CHECK(in_sequence(ranges::begin(rng), result.in, ranges::end(rng)));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, b));
         }
 
         {
             auto result = ranges::sample(i, b.begin(), K, g2);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(ranges::equal(a, b));
         }
 
         {
             auto result = ranges::sample(i, b.begin(), K, g1);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(!ranges::equal(a, b));
             CHECK(!ranges::equal(b, c));
         }
@@ -112,8 +114,8 @@ int main()
         {
             a.fill(0);
             auto result = ranges::sample(std::move(rng), a.begin(), K, g1);
-            CHECK(in_sequence(ranges::begin(rng), result.in().get_unsafe(), ranges::end(rng)));
-            CHECK(result.out() == a.end());
+            CHECK(in_sequence(ranges::begin(rng), result.in, ranges::end(rng)));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, c));
         }
     }
@@ -124,17 +126,17 @@ int main()
         std::array<int, K> a{}, b{}, c{};
 
         {
-            auto result = ranges::sample(random_access_iterator<int*>(i.data()),
-                sentinel<int*>(i.data() + N), a.begin(), K);
-            CHECK(in_sequence(i.data(), result.in().base(), i.data() + N));
-            CHECK(result.out() == a.end());
+            auto result = ranges::sample(RandomAccessIterator<int*>(i.data()),
+                Sentinel<int*>(i.data() + N), a.begin(), K);
+            CHECK(in_sequence(i.data(), result.in.base(), i.data() + N));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, b));
         }
 
         {
             auto result = ranges::sample(i, b.begin(), K);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(!ranges::equal(b, c));
             CHECK(!ranges::equal(a, b));
         }
@@ -145,11 +147,11 @@ int main()
         std::array<MoveOnlyString, 4> dest;
         auto result = ranges::sample(ranges::make_move_iterator(source.begin()),
             ranges::make_move_sentinel(source.end()),
-            forward_iterator<MoveOnlyString*>(dest.data()), dest.size());
+            ForwardIterator<MoveOnlyString*>(dest.data()), dest.size());
         CHECK(in_sequence(ranges::make_move_iterator(source.begin()),
-            result.in(),
+            result.in,
             ranges::make_move_sentinel(source.end())));
-        CHECK(result.out() == forward_iterator<MoveOnlyString*>(dest.data() + dest.size()));
+        CHECK(result.out == ForwardIterator<MoveOnlyString*>(dest.data() + dest.size()));
     }
 
     {
@@ -159,25 +161,25 @@ int main()
         std::minstd_rand g1, g2 = g1;
 
         {
-            auto result = ranges::sample(random_access_iterator<int*>(i.data()),
-                sentinel<int*>(i.data()+N), a, g1);
-            CHECK(in_sequence(i.data(), result.in().base(), i.data() + N));
-            CHECK(result.out() == a.end());
+            auto result = ranges::sample(RandomAccessIterator<int*>(i.data()),
+                Sentinel<int*>(i.data()+N), a, g1);
+            CHECK(in_sequence(i.data(), result.in.base(), i.data() + N));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, c));
         }
 
         {
             auto result = ranges::sample(i.begin(), i.end(), b, g1);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(!ranges::equal(a, b));
             CHECK(!ranges::equal(b, c));
         }
 
         {
             auto result = ranges::sample(i.begin(), i.end(), c, g2);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == c.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == c.end());
             CHECK(ranges::equal(a, c));
         }
     }
@@ -187,26 +189,26 @@ int main()
         ranges::iota(i, 0);
         std::array<int, K> a{}, b{}, c{};
         std::minstd_rand g1, g2 = g1;
-        auto rng = ranges::make_iterator_range(random_access_iterator<int*>(i.data()), sentinel<int*>(i.data() + N));
+        auto rng = ranges::make_subrange(RandomAccessIterator<int*>(i.data()), Sentinel<int*>(i.data() + N));
 
         {
             auto result = ranges::sample(rng, a, g1);
-            CHECK(in_sequence(i.data(), result.in().base(), i.data() + N));
-            CHECK(result.out() == a.end());
+            CHECK(in_sequence(i.data(), result.in.base(), i.data() + N));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, b));
         }
 
         {
             auto result = ranges::sample(i, b, g2);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(ranges::equal(a, b));
         }
 
         {
             auto result = ranges::sample(i, b, g1);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(!ranges::equal(a, b));
             CHECK(!ranges::equal(b, c));
         }
@@ -214,8 +216,8 @@ int main()
         {
             a.fill(0);
             auto result = ranges::sample(std::move(rng), a, g1);
-            CHECK(in_sequence(i.data(), result.in().get_unsafe().base(), i.data() + N));
-            CHECK(result.out() == a.end());
+            CHECK(in_sequence(i.data(), result.in.base(), i.data() + N));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, c));
         }
     }
@@ -226,17 +228,17 @@ int main()
         std::array<int, K> a{}, b{}, c{};
 
         {
-            auto result = ranges::sample(random_access_iterator<int*>(i.data()),
-                sentinel<int*>(i.data() + N), a);
-            CHECK(in_sequence(i.data(), result.in().base(), i.data() + N));
-            CHECK(result.out() == a.end());
+            auto result = ranges::sample(RandomAccessIterator<int*>(i.data()),
+                Sentinel<int*>(i.data() + N), a);
+            CHECK(in_sequence(i.data(), result.in.base(), i.data() + N));
+            CHECK(result.out == a.end());
             CHECK(!ranges::equal(a, b));
         }
 
         {
             auto result = ranges::sample(i, b);
-            CHECK(in_sequence(i.begin(), result.in(), i.end()));
-            CHECK(result.out() == b.end());
+            CHECK(in_sequence(i.begin(), result.in, i.end()));
+            CHECK(result.out == b.end());
             CHECK(!ranges::equal(b, c));
             CHECK(!ranges::equal(a, b));
         }
@@ -245,13 +247,13 @@ int main()
     {
         std::array<MoveOnlyString, 10> source;
         std::array<MoveOnlyString, 4> dest;
-        auto out = ranges::make_iterator_range(
-            forward_iterator<MoveOnlyString*>(dest.data()),
-            sentinel<MoveOnlyString*, true>(dest.data() + dest.size()));
+        auto out = ranges::make_subrange(
+            ForwardIterator<MoveOnlyString*>(dest.data()),
+            Sentinel<MoveOnlyString*, true>(dest.data() + dest.size()));
         auto result = ranges::sample(ranges::make_move_iterator(source.begin()),
             ranges::make_move_sentinel(source.end()), out);
-        CHECK(in_sequence(source.begin(), result.in().base(), source.end()));
-        CHECK(result.out() == ranges::end(out));
+        CHECK(in_sequence(source.begin(), result.in.base(), source.end()));
+        CHECK(result.out == ranges::end(out));
     }
 
     {
@@ -260,18 +262,18 @@ int main()
         std::minstd_rand g;
         {
             auto result = ranges::sample(data, sample, g);
-            CHECK(in_sequence(ranges::begin(data), result.in(), ranges::end(data)));
-            CHECK(result.out() == ranges::end(sample));
+            CHECK(in_sequence(ranges::begin(data), result.in, ranges::end(data)));
+            CHECK(result.out == ranges::end(sample));
         }
         {
             auto result = ranges::sample(data, sample);
-            CHECK(in_sequence(ranges::begin(data), result.in(), ranges::end(data)));
-            CHECK(result.out() == ranges::end(sample));
+            CHECK(in_sequence(ranges::begin(data), result.in, ranges::end(data)));
+            CHECK(result.out == ranges::end(sample));
         }
         {
             auto result = ranges::sample(data + 0, data + 2, sample + 0, 9999);
-            CHECK(result.in() == data + 2);
-            CHECK(result.out() == sample + 2);
+            CHECK(result.in == data + 2);
+            CHECK(result.out == sample + 2);
         }
     }
 
