@@ -32,9 +32,10 @@ void test_iter_3()
 {
     int i[3] = {1, 2, 3};
     int j[3] = {4, 5, 6};
-    std::pair<Iter1, Iter2> r = ranges::swap_ranges(Iter1(i), Iter1(i+3), Iter2(j));
-    CHECK(base(r.first) == i+3);
-    CHECK(base(r.second) == j+3);
+    ranges::swap_ranges_result<Iter1, Iter2> r =
+        ranges::swap_ranges(Iter1(i), Iter1(i+3), Iter2(j));
+    CHECK(base(r.in1) == i+3);
+    CHECK(base(r.in2) == j+3);
     CHECK(i[0] == 4);
     CHECK(i[1] == 5);
     CHECK(i[2] == 6);
@@ -44,8 +45,8 @@ void test_iter_3()
 
     using Sent1 = typename sentinel_type<Iter1>::type;
     r = ranges::swap_ranges(Iter1(j), Sent1(j+3), Iter2(i));
-    CHECK(base(r.first) == j+3);
-    CHECK(base(r.second) == i+3);
+    CHECK(base(r.in1) == j+3);
+    CHECK(base(r.in2) == i+3);
     CHECK(i[0] == 1);
     CHECK(i[1] == 2);
     CHECK(i[2] == 3);
@@ -59,9 +60,10 @@ void test_iter_4()
 {
     int i[3] = {1, 2, 3};
     int j[4] = {4, 5, 6, 7};
-    std::pair<Iter1, Iter2> r = ranges::swap_ranges(Iter1(i), Iter1(i+3), Iter2(j), Iter2(j+4));
-    CHECK(base(r.first) == i+3);
-    CHECK(base(r.second) == j+3);
+    ranges::swap_ranges_result<Iter1, Iter2> r =
+        ranges::swap_ranges(Iter1(i), Iter1(i+3), Iter2(j), Iter2(j+4));
+    CHECK(base(r.in1) == i+3);
+    CHECK(base(r.in2) == j+3);
     CHECK(i[0] == 4);
     CHECK(i[1] == 5);
     CHECK(i[2] == 6);
@@ -73,8 +75,8 @@ void test_iter_4()
     using Sent1 = typename sentinel_type<Iter1>::type;
     using Sent2 = typename sentinel_type<Iter2>::type;
     r = ranges::swap_ranges(Iter1(j), Sent1(j+4), Iter2(i), Sent2(i+3));
-    CHECK(base(r.first) == j+3);
-    CHECK(base(r.second) == i+3);
+    CHECK(base(r.in1) == j+3);
+    CHECK(base(r.in2) == i+3);
     CHECK(i[0] == 1);
     CHECK(i[1] == 2);
     CHECK(i[2] == 3);
@@ -89,9 +91,10 @@ void test_rng_3()
 {
     int i[3] = {1, 2, 3};
     int j[3] = {4, 5, 6};
-    std::pair<Iter1, Iter2> r = ranges::swap_ranges(as_lvalue(ranges::make_iterator_range(Iter1(i), Iter1(i+3))), Iter2(j));
-    CHECK(base(r.first) == i+3);
-    CHECK(base(r.second) == j+3);
+    ranges::swap_ranges_result<Iter1, Iter2> r =
+        ranges::swap_ranges(as_lvalue(ranges::make_subrange(Iter1(i), Iter1(i+3))), Iter2(j));
+    CHECK(base(r.in1) == i+3);
+    CHECK(base(r.in2) == j+3);
     CHECK(i[0] == 4);
     CHECK(i[1] == 5);
     CHECK(i[2] == 6);
@@ -100,9 +103,9 @@ void test_rng_3()
     CHECK(j[2] == 3);
 
     using Sent1 = typename sentinel_type<Iter1>::type;
-    r = ranges::swap_ranges(as_lvalue(ranges::make_iterator_range(Iter1(j), Sent1(j+3))), Iter2(i));
-    CHECK(base(r.first) == j+3);
-    CHECK(base(r.second) == i+3);
+    r = ranges::swap_ranges(as_lvalue(ranges::make_subrange(Iter1(j), Sent1(j+3))), Iter2(i));
+    CHECK(base(r.in1) == j+3);
+    CHECK(base(r.in2) == i+3);
     CHECK(i[0] == 1);
     CHECK(i[1] == 2);
     CHECK(i[2] == 3);
@@ -116,11 +119,11 @@ void test_rng_4()
 {
     int i[3] = {1, 2, 3};
     int j[4] = {4, 5, 6, 7};
-    std::pair<Iter1, Iter2> r = ranges::swap_ranges(
-        as_lvalue(ranges::make_iterator_range(Iter1(i), Iter1(i+3))),
-        as_lvalue(ranges::make_iterator_range(Iter2(j), Iter2(j+4))));
-    CHECK(base(r.first) == i+3);
-    CHECK(base(r.second) == j+3);
+    ranges::swap_ranges_result<Iter1, Iter2> r = ranges::swap_ranges(
+        as_lvalue(ranges::make_subrange(Iter1(i), Iter1(i+3))),
+        as_lvalue(ranges::make_subrange(Iter2(j), Iter2(j+4))));
+    CHECK(base(r.in1) == i+3);
+    CHECK(base(r.in2) == j+3);
     CHECK(i[0] == 4);
     CHECK(i[1] == 5);
     CHECK(i[2] == 6);
@@ -132,10 +135,10 @@ void test_rng_4()
     using Sent1 = typename sentinel_type<Iter1>::type;
     using Sent2 = typename sentinel_type<Iter2>::type;
     r = ranges::swap_ranges(
-        as_lvalue(ranges::make_iterator_range(Iter1(j), Sent1(j+4))),
-        as_lvalue(ranges::make_iterator_range(Iter2(i), Sent2(i+3))));
-    CHECK(base(r.first) == j+3);
-    CHECK(base(r.second) == i+3);
+        as_lvalue(ranges::make_subrange(Iter1(j), Sent1(j+4))),
+        as_lvalue(ranges::make_subrange(Iter2(i), Sent2(i+3))));
+    CHECK(base(r.in1) == j+3);
+    CHECK(base(r.in2) == i+3);
     CHECK(i[0] == 1);
     CHECK(i[1] == 2);
     CHECK(i[2] == 3);
@@ -145,10 +148,10 @@ void test_rng_4()
     CHECK(j[3] == 7);
 
     auto r2 = ranges::swap_ranges(
-        ranges::make_iterator_range(Iter1(j), Sent1(j+4)),
-        ranges::make_iterator_range(Iter2(i), Sent2(i+3)));
-    CHECK(base(r2.first.get_unsafe()) == j+3);
-    CHECK(base(r2.second.get_unsafe()) == i+3);
+        ranges::make_subrange(Iter1(j), Sent1(j+4)),
+        ranges::make_subrange(Iter2(i), Sent2(i+3)));
+    CHECK(base(r2.in1) == j+3);
+    CHECK(base(r2.in2) == i+3);
     CHECK(i[0] == 4);
     CHECK(i[1] == 5);
     CHECK(i[2] == 6);
@@ -167,9 +170,10 @@ void test_move_only()
     std::unique_ptr<int> j[3];
     for (int k = 0; k < 3; ++k)
         j[k].reset(new int(k+4));
-    std::pair<Iter1, Iter2> r = ranges::swap_ranges(Iter1(i), Iter1(i+3), Iter2(j));
-    CHECK(base(r.first) == i+3);
-    CHECK(base(r.second) == j+3);
+    ranges::swap_ranges_result<Iter1, Iter2> r =
+        ranges::swap_ranges(Iter1(i), Iter1(i+3), Iter2(j));
+    CHECK(base(r.in1) == i+3);
+    CHECK(base(r.in2) == j+3);
     CHECK(*i[0] == 4);
     CHECK(*i[1] == 5);
     CHECK(*i[2] == 6);
@@ -189,44 +193,44 @@ void test()
 
 int main()
 {
-    test<forward_iterator<int*>, forward_iterator<int*> >();
-    test<forward_iterator<int*>, bidirectional_iterator<int*> >();
-    test<forward_iterator<int*>, random_access_iterator<int*> >();
-    test<forward_iterator<int*>, int*>();
+    test<ForwardIterator<int*>, ForwardIterator<int*> >();
+    test<ForwardIterator<int*>, BidirectionalIterator<int*> >();
+    test<ForwardIterator<int*>, RandomAccessIterator<int*> >();
+    test<ForwardIterator<int*>, int*>();
 
-    test<bidirectional_iterator<int*>, forward_iterator<int*> >();
-    test<bidirectional_iterator<int*>, bidirectional_iterator<int*> >();
-    test<bidirectional_iterator<int*>, random_access_iterator<int*> >();
-    test<bidirectional_iterator<int*>, int*>();
+    test<BidirectionalIterator<int*>, ForwardIterator<int*> >();
+    test<BidirectionalIterator<int*>, BidirectionalIterator<int*> >();
+    test<BidirectionalIterator<int*>, RandomAccessIterator<int*> >();
+    test<BidirectionalIterator<int*>, int*>();
 
-    test<random_access_iterator<int*>, forward_iterator<int*> >();
-    test<random_access_iterator<int*>, bidirectional_iterator<int*> >();
-    test<random_access_iterator<int*>, random_access_iterator<int*> >();
-    test<random_access_iterator<int*>, int*>();
+    test<RandomAccessIterator<int*>, ForwardIterator<int*> >();
+    test<RandomAccessIterator<int*>, BidirectionalIterator<int*> >();
+    test<RandomAccessIterator<int*>, RandomAccessIterator<int*> >();
+    test<RandomAccessIterator<int*>, int*>();
 
-    test<int*, forward_iterator<int*> >();
-    test<int*, bidirectional_iterator<int*> >();
-    test<int*, random_access_iterator<int*> >();
+    test<int*, ForwardIterator<int*> >();
+    test<int*, BidirectionalIterator<int*> >();
+    test<int*, RandomAccessIterator<int*> >();
     test<int*, int*>();
 
-    test_move_only<forward_iterator<std::unique_ptr<int>*>, forward_iterator<std::unique_ptr<int>*> >();
-    test_move_only<forward_iterator<std::unique_ptr<int>*>, bidirectional_iterator<std::unique_ptr<int>*> >();
-    test_move_only<forward_iterator<std::unique_ptr<int>*>, random_access_iterator<std::unique_ptr<int>*> >();
-    test_move_only<forward_iterator<std::unique_ptr<int>*>, std::unique_ptr<int>*>();
+    test_move_only<ForwardIterator<std::unique_ptr<int>*>, ForwardIterator<std::unique_ptr<int>*> >();
+    test_move_only<ForwardIterator<std::unique_ptr<int>*>, BidirectionalIterator<std::unique_ptr<int>*> >();
+    test_move_only<ForwardIterator<std::unique_ptr<int>*>, RandomAccessIterator<std::unique_ptr<int>*> >();
+    test_move_only<ForwardIterator<std::unique_ptr<int>*>, std::unique_ptr<int>*>();
 
-    test_move_only<bidirectional_iterator<std::unique_ptr<int>*>, forward_iterator<std::unique_ptr<int>*> >();
-    test_move_only<bidirectional_iterator<std::unique_ptr<int>*>, bidirectional_iterator<std::unique_ptr<int>*> >();
-    test_move_only<bidirectional_iterator<std::unique_ptr<int>*>, random_access_iterator<std::unique_ptr<int>*> >();
-    test_move_only<bidirectional_iterator<std::unique_ptr<int>*>, std::unique_ptr<int>*>();
+    test_move_only<BidirectionalIterator<std::unique_ptr<int>*>, ForwardIterator<std::unique_ptr<int>*> >();
+    test_move_only<BidirectionalIterator<std::unique_ptr<int>*>, BidirectionalIterator<std::unique_ptr<int>*> >();
+    test_move_only<BidirectionalIterator<std::unique_ptr<int>*>, RandomAccessIterator<std::unique_ptr<int>*> >();
+    test_move_only<BidirectionalIterator<std::unique_ptr<int>*>, std::unique_ptr<int>*>();
 
-    test_move_only<random_access_iterator<std::unique_ptr<int>*>, forward_iterator<std::unique_ptr<int>*> >();
-    test_move_only<random_access_iterator<std::unique_ptr<int>*>, bidirectional_iterator<std::unique_ptr<int>*> >();
-    test_move_only<random_access_iterator<std::unique_ptr<int>*>, random_access_iterator<std::unique_ptr<int>*> >();
-    test_move_only<random_access_iterator<std::unique_ptr<int>*>, std::unique_ptr<int>*>();
+    test_move_only<RandomAccessIterator<std::unique_ptr<int>*>, ForwardIterator<std::unique_ptr<int>*> >();
+    test_move_only<RandomAccessIterator<std::unique_ptr<int>*>, BidirectionalIterator<std::unique_ptr<int>*> >();
+    test_move_only<RandomAccessIterator<std::unique_ptr<int>*>, RandomAccessIterator<std::unique_ptr<int>*> >();
+    test_move_only<RandomAccessIterator<std::unique_ptr<int>*>, std::unique_ptr<int>*>();
 
-    test_move_only<std::unique_ptr<int>*, forward_iterator<std::unique_ptr<int>*> >();
-    test_move_only<std::unique_ptr<int>*, bidirectional_iterator<std::unique_ptr<int>*> >();
-    test_move_only<std::unique_ptr<int>*, random_access_iterator<std::unique_ptr<int>*> >();
+    test_move_only<std::unique_ptr<int>*, ForwardIterator<std::unique_ptr<int>*> >();
+    test_move_only<std::unique_ptr<int>*, BidirectionalIterator<std::unique_ptr<int>*> >();
+    test_move_only<std::unique_ptr<int>*, RandomAccessIterator<std::unique_ptr<int>*> >();
     test_move_only<std::unique_ptr<int>*, std::unique_ptr<int>*>();
 
     {
