@@ -26,6 +26,7 @@
 //   http://http://libcxx.llvm.org/
 
 #include <cstring>
+#include <vector>
 #include <range/v3/core.hpp>
 #include <range/v3/algorithm/unique_copy.hpp>
 #include "../simple_test.hpp"
@@ -50,9 +51,9 @@ test_iter()
     const unsigned sa = sizeof(ia)/sizeof(ia[0]);
     int ja[sa] = {-1};
     count_equal::count = 0;
-    std::pair<InIter, OutIter> r = ranges::unique_copy(InIter(ia), Sent(ia+sa), OutIter(ja), count_equal());
-    CHECK(base(r.first) == ia + sa);
-    CHECK(base(r.second) == ja + sa);
+    ranges::unique_copy_result<InIter, OutIter> r = ranges::unique_copy(InIter(ia), Sent(ia+sa), OutIter(ja), count_equal());
+    CHECK(base(r.in) == ia + sa);
+    CHECK(base(r.out) == ja + sa);
     CHECK(ja[0] == 0);
     CHECK(count_equal::count == sa-1);
 
@@ -61,8 +62,8 @@ test_iter()
     int jb[sb] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(ib), Sent(ib+sb), OutIter(jb), count_equal());
-    CHECK(base(r.first) == ib + sb);
-    CHECK(base(r.second) == jb + sb);
+    CHECK(base(r.in) == ib + sb);
+    CHECK(base(r.out) == jb + sb);
     CHECK(jb[0] == 0);
     CHECK(jb[1] == 1);
     CHECK(count_equal::count == sb-1);
@@ -72,8 +73,8 @@ test_iter()
     int jc[sc] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(ic), Sent(ic+sc), OutIter(jc), count_equal());
-    CHECK(base(r.first) == ic + sc);
-    CHECK(base(r.second) == jc + 1);
+    CHECK(base(r.in) == ic + sc);
+    CHECK(base(r.out) == jc + 1);
     CHECK(jc[0] == 0);
     CHECK(count_equal::count == sc-1);
 
@@ -82,8 +83,8 @@ test_iter()
     int jd[sd] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(id), Sent(id+sd), OutIter(jd), count_equal());
-    CHECK(base(r.first) == id + sd);
-    CHECK(base(r.second) == jd + 2);
+    CHECK(base(r.in) == id + sd);
+    CHECK(base(r.out) == jd + 2);
     CHECK(jd[0] == 0);
     CHECK(jd[1] == 1);
     CHECK(count_equal::count == sd-1);
@@ -93,8 +94,8 @@ test_iter()
     int je[se] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(ie), Sent(ie+se), OutIter(je), count_equal());
-    CHECK(base(r.first) == ie + se);
-    CHECK(base(r.second) == je + 3);
+    CHECK(base(r.in) == ie + se);
+    CHECK(base(r.out) == je + 3);
     CHECK(je[0] == 0);
     CHECK(je[1] == 1);
     CHECK(je[2] == 0);
@@ -105,8 +106,8 @@ test_iter()
     int jg[sg] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(ig), Sent(ig+sg), OutIter(jg), count_equal());
-    CHECK(base(r.first) == ig + sg);
-    CHECK(base(r.second) == jg + 2);
+    CHECK(base(r.in) == ig + sg);
+    CHECK(base(r.out) == jg + 2);
     CHECK(jg[0] == 0);
     CHECK(jg[1] == 1);
     CHECK(count_equal::count == sg-1);
@@ -116,8 +117,8 @@ test_iter()
     int jh[sh] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(ih), Sent(ih+sh), OutIter(jh), count_equal());
-    CHECK(base(r.first) == ih + sh);
-    CHECK(base(r.second) == jh + 2);
+    CHECK(base(r.in) == ih + sh);
+    CHECK(base(r.out) == jh + 2);
     CHECK(jh[0] == 0);
     CHECK(jh[1] == 1);
     CHECK(count_equal::count == sh-1);
@@ -127,8 +128,8 @@ test_iter()
     int ji[si] = {-1};
     count_equal::count = 0;
     r = ranges::unique_copy(InIter(ii), Sent(ii+si), OutIter(ji), count_equal());
-    CHECK(base(r.first) == ii + si);
-    CHECK(base(r.second) == ji + 3);
+    CHECK(base(r.in) == ii + si);
+    CHECK(base(r.out) == ji + 3);
     CHECK(ji[0] == 0);
     CHECK(ji[1] == 1);
     CHECK(ji[2] == 2);
@@ -143,9 +144,9 @@ test_range()
     const unsigned sa = sizeof(ia)/sizeof(ia[0]);
     int ja[sa] = {-1};
     count_equal::count = 0;
-    std::pair<InIter, OutIter> r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ia), Sent(ia+sa))), OutIter(ja), count_equal());
-    CHECK(base(r.first) == ia + sa);
-    CHECK(base(r.second) == ja + sa);
+    ranges::unique_copy_result<InIter, OutIter> r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ia), Sent(ia+sa))), OutIter(ja), count_equal());
+    CHECK(base(r.in) == ia + sa);
+    CHECK(base(r.out) == ja + sa);
     CHECK(ja[0] == 0);
     CHECK(count_equal::count == sa-1);
 
@@ -153,9 +154,9 @@ test_range()
     const unsigned sb = sizeof(ib)/sizeof(ib[0]);
     int jb[sb] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ib), Sent(ib+sb))), OutIter(jb), count_equal());
-    CHECK(base(r.first) == ib + sb);
-    CHECK(base(r.second) == jb + sb);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ib), Sent(ib+sb))), OutIter(jb), count_equal());
+    CHECK(base(r.in) == ib + sb);
+    CHECK(base(r.out) == jb + sb);
     CHECK(jb[0] == 0);
     CHECK(jb[1] == 1);
     CHECK(count_equal::count == sb-1);
@@ -164,9 +165,9 @@ test_range()
     const unsigned sc = sizeof(ic)/sizeof(ic[0]);
     int jc[sc] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ic), Sent(ic+sc))), OutIter(jc), count_equal());
-    CHECK(base(r.first) == ic + sc);
-    CHECK(base(r.second) == jc + 1);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ic), Sent(ic+sc))), OutIter(jc), count_equal());
+    CHECK(base(r.in) == ic + sc);
+    CHECK(base(r.out) == jc + 1);
     CHECK(jc[0] == 0);
     CHECK(count_equal::count == sc-1);
 
@@ -174,9 +175,9 @@ test_range()
     const unsigned sd = sizeof(id)/sizeof(id[0]);
     int jd[sd] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(id), Sent(id+sd))), OutIter(jd), count_equal());
-    CHECK(base(r.first) == id + sd);
-    CHECK(base(r.second) == jd + 2);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(id), Sent(id+sd))), OutIter(jd), count_equal());
+    CHECK(base(r.in) == id + sd);
+    CHECK(base(r.out) == jd + 2);
     CHECK(jd[0] == 0);
     CHECK(jd[1] == 1);
     CHECK(count_equal::count == sd-1);
@@ -185,9 +186,9 @@ test_range()
     const unsigned se = sizeof(ie)/sizeof(ie[0]);
     int je[se] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ie), Sent(ie+se))), OutIter(je), count_equal());
-    CHECK(base(r.first) == ie + se);
-    CHECK(base(r.second) == je + 3);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ie), Sent(ie+se))), OutIter(je), count_equal());
+    CHECK(base(r.in) == ie + se);
+    CHECK(base(r.out) == je + 3);
     CHECK(je[0] == 0);
     CHECK(je[1] == 1);
     CHECK(je[2] == 0);
@@ -197,9 +198,9 @@ test_range()
     const unsigned sg = sizeof(ig)/sizeof(ig[0]);
     int jg[sg] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ig), Sent(ig+sg))), OutIter(jg), count_equal());
-    CHECK(base(r.first) == ig + sg);
-    CHECK(base(r.second) == jg + 2);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ig), Sent(ig+sg))), OutIter(jg), count_equal());
+    CHECK(base(r.in) == ig + sg);
+    CHECK(base(r.out) == jg + 2);
     CHECK(jg[0] == 0);
     CHECK(jg[1] == 1);
     CHECK(count_equal::count == sg-1);
@@ -208,9 +209,9 @@ test_range()
     const unsigned sh = sizeof(ih)/sizeof(ih[0]);
     int jh[sh] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ih), Sent(ih+sh))), OutIter(jh), count_equal());
-    CHECK(base(r.first) == ih + sh);
-    CHECK(base(r.second) == jh + 2);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ih), Sent(ih+sh))), OutIter(jh), count_equal());
+    CHECK(base(r.in) == ih + sh);
+    CHECK(base(r.out) == jh + 2);
     CHECK(jh[0] == 0);
     CHECK(jh[1] == 1);
     CHECK(count_equal::count == sh-1);
@@ -219,9 +220,9 @@ test_range()
     const unsigned si = sizeof(ii)/sizeof(ii[0]);
     int ji[si] = {-1};
     count_equal::count = 0;
-    r = ranges::unique_copy(::as_lvalue(ranges::make_iterator_range(InIter(ii), Sent(ii+si))), OutIter(ji), count_equal());
-    CHECK(base(r.first) == ii + si);
-    CHECK(base(r.second) == ji + 3);
+    r = ranges::unique_copy(::as_lvalue(ranges::make_subrange(InIter(ii), Sent(ii+si))), OutIter(ji), count_equal());
+    CHECK(base(r.in) == ii + si);
+    CHECK(base(r.out) == ji + 3);
     CHECK(ji[0] == 0);
     CHECK(ji[1] == 1);
     CHECK(ji[2] == 2);
@@ -251,54 +252,73 @@ bool operator==(S l, S r)
 
 int main()
 {
-    test<input_iterator<const int*>, output_iterator<int*> >();
-    test<input_iterator<const int*>, forward_iterator<int*> >();
-    test<input_iterator<const int*>, bidirectional_iterator<int*> >();
-    test<input_iterator<const int*>, random_access_iterator<int*> >();
-    test<input_iterator<const int*>, int*>();
+    test<InputIterator<const int*>, OutputIterator<int*> >();
+    test<InputIterator<const int*>, ForwardIterator<int*> >();
+    test<InputIterator<const int*>, BidirectionalIterator<int*> >();
+    test<InputIterator<const int*>, RandomAccessIterator<int*> >();
+    test<InputIterator<const int*>, int*>();
 
-    test<forward_iterator<const int*>, output_iterator<int*> >();
-    test<forward_iterator<const int*>, forward_iterator<int*> >();
-    test<forward_iterator<const int*>, bidirectional_iterator<int*> >();
-    test<forward_iterator<const int*>, random_access_iterator<int*> >();
-    test<forward_iterator<const int*>, int*>();
+    test<ForwardIterator<const int*>, OutputIterator<int*> >();
+    test<ForwardIterator<const int*>, ForwardIterator<int*> >();
+    test<ForwardIterator<const int*>, BidirectionalIterator<int*> >();
+    test<ForwardIterator<const int*>, RandomAccessIterator<int*> >();
+    test<ForwardIterator<const int*>, int*>();
 
-    test<bidirectional_iterator<const int*>, output_iterator<int*> >();
-    test<bidirectional_iterator<const int*>, forward_iterator<int*> >();
-    test<bidirectional_iterator<const int*>, bidirectional_iterator<int*> >();
-    test<bidirectional_iterator<const int*>, random_access_iterator<int*> >();
-    test<bidirectional_iterator<const int*>, int*>();
+    test<BidirectionalIterator<const int*>, OutputIterator<int*> >();
+    test<BidirectionalIterator<const int*>, ForwardIterator<int*> >();
+    test<BidirectionalIterator<const int*>, BidirectionalIterator<int*> >();
+    test<BidirectionalIterator<const int*>, RandomAccessIterator<int*> >();
+    test<BidirectionalIterator<const int*>, int*>();
 
-    test<random_access_iterator<const int*>, output_iterator<int*> >();
-    test<random_access_iterator<const int*>, forward_iterator<int*> >();
-    test<random_access_iterator<const int*>, bidirectional_iterator<int*> >();
-    test<random_access_iterator<const int*>, random_access_iterator<int*> >();
-    test<random_access_iterator<const int*>, int*>();
+    test<RandomAccessIterator<const int*>, OutputIterator<int*> >();
+    test<RandomAccessIterator<const int*>, ForwardIterator<int*> >();
+    test<RandomAccessIterator<const int*>, BidirectionalIterator<int*> >();
+    test<RandomAccessIterator<const int*>, RandomAccessIterator<int*> >();
+    test<RandomAccessIterator<const int*>, int*>();
 
-    test<const int*, output_iterator<int*> >();
-    test<const int*, forward_iterator<int*> >();
-    test<const int*, bidirectional_iterator<int*> >();
-    test<const int*, random_access_iterator<int*> >();
+    test<const int*, OutputIterator<int*> >();
+    test<const int*, ForwardIterator<int*> >();
+    test<const int*, BidirectionalIterator<int*> >();
+    test<const int*, RandomAccessIterator<int*> >();
     test<const int*, int*>();
 
     // Test projections:
     {
         S const ia[] = {{1,1},{2,2},{3,3},{3,4},{4,5},{5,6},{5,7},{5,8},{6,9},{7,10}};
         S ib[ranges::size(ia)];
-        std::pair<S const *, S *> r = ranges::unique_copy(ia, ib, ranges::equal_to(), &S::i);
-        CHECK(r.first == ranges::end(ia));
-        CHECK(r.second == ib + 7);
-        check_equal(ranges::make_iterator_range(ib, ib+7), {S{1,1},S{2,2},S{3,3},S{4,5},S{5,6},S{6,9},S{7,10}});
+        ranges::unique_copy_result<S const *, S *> r = ranges::unique_copy(ia, ib, ranges::equal_to(), &S::i);
+        CHECK(r.in == ranges::end(ia));
+        CHECK(r.out == ib + 7);
+        check_equal(ranges::make_subrange(ib, ib+7), {S{1,1},S{2,2},S{3,3},S{4,5},S{5,6},S{6,9},S{7,10}});
     }
 
     // Test rvalue ranges:
     {
         S const ia[] = {{1,1},{2,2},{3,3},{3,4},{4,5},{5,6},{5,7},{5,8},{6,9},{7,10}};
         S ib[ranges::size(ia)];
-        auto r = ranges::unique_copy(ranges::view::all(ia), ib, ranges::equal_to(), &S::i);
-        CHECK(r.first.get_unsafe() == ranges::end(ia));
-        CHECK(r.second == ib + 7);
-        check_equal(ranges::make_iterator_range(ib, ib+7), {S{1,1},S{2,2},S{3,3},S{4,5},S{5,6},S{6,9},S{7,10}});
+        auto r = ranges::unique_copy(ranges::views::all(ia), ib, ranges::equal_to(), &S::i);
+        CHECK(r.in == ranges::end(ia));
+        CHECK(r.out == ib + 7);
+        check_equal(ranges::make_subrange(ib, ib+7), {S{1,1},S{2,2},S{3,3},S{4,5},S{5,6},S{6,9},S{7,10}});
+    }
+#ifndef RANGES_WORKAROUND_MSVC_573728
+    {
+        S const ia[] = {{1,1},{2,2},{3,3},{3,4},{4,5},{5,6},{5,7},{5,8},{6,9},{7,10}};
+        S ib[ranges::size(ia)];
+        auto r = ranges::unique_copy(std::move(ia), ib, ranges::equal_to(), &S::i);
+        CHECK(::is_dangling(r.in));
+        CHECK(r.out == ib + 7);
+        check_equal(ranges::make_subrange(ib, ib+7), {S{1,1},S{2,2},S{3,3},S{4,5},S{5,6},S{6,9},S{7,10}});
+    }
+#endif // RANGES_WORKAROUND_MSVC_573728
+    {
+        std::vector<S> const ia{{1,1},{2,2},{3,3},{3,4},{4,5},{5,6},{5,7},{5,8},{6,9},{7,10}};
+        S ib[10];
+        RANGES_ENSURE(ranges::size(ia) == ranges::size(ib));
+        auto r = ranges::unique_copy(std::move(ia), ib, ranges::equal_to(), &S::i);
+        CHECK(::is_dangling(r.in));
+        CHECK(r.out == ib + 7);
+        check_equal(ranges::make_subrange(ib, ib+7), {S{1,1},S{2,2},S{3,3},S{4,5},S{5,6},S{6,9},S{7,10}});
     }
 
     return ::test_result();
